@@ -1,3 +1,20 @@
+to_strtime_handler <- function(format = NULL, tz = NULL) {
+  if (is.null(format)) {
+    format <- "%H%M%OS"
+  }
+  if (is.null(tz)) {
+    tz <- "GMT"
+  }
+  handler <- function(x) {
+    z <- str_pad(x, 9, pad = "0") |> str_match("(\\d{6})(\\d{3})")
+    t <- str_c(z[, 2], ".", z[, 3])
+    strptime(t, format = format, tz = tz)
+  }
+  attr(handler, "format") <- format
+  attr(handler, "type") <- "strtime"
+  class(handler) <- c("function", "handler")
+  handler
+}
 
 new_field <- function(x) {
   width_ <- if (!is.null(x$width)) width(x$width)
@@ -11,6 +28,8 @@ new_field <- function(x) {
     handler_ <- to_date_handler(x$handler$format)
   } else if (x$handler$type == "POSIXct") {
     handler_ <- to_time_handler(x$handler$format)
+  } else if (x$handler$type == "strtime") {
+    handler_ <- to_strtime_handler(x$handler$format)
   } else {
     handler_ <- pass_thru_handler()
   }
@@ -37,7 +56,6 @@ new_part <- function(x) {
   }
 }
 
-#' @importFrom utils getFromNamespace
 new_template <- function(tpl) {
   obj <- MarketData$proto()
   obj[["has_reader"]] <- FALSE
@@ -63,7 +81,7 @@ new_template <- function(tpl) {
   }
 
   if (is(try(obj$reader, TRUE), "try-error")) {
-    reader_name <- paste0(stringr::str_to_lower(obj$filetype), "_read_file")
+    reader_name <- paste0(str_to_lower(obj$filetype), "_read_file")
     obj[["read_file"]] <- getFromNamespace(reader_name, "rb3")
     obj[["has_reader"]] <- TRUE
   }
@@ -83,12 +101,23 @@ load_templates <- function() {
   )
   files <- list.files(dir, full.names = TRUE)
   for (file in files) {
-    tpl <- yaml::yaml.load_file(file)
+    tpl <- yaml.load_file(file)
     new_template(tpl)
   }
 }
 
 .onAttach <- function(libname, pkgname) {
   load_templates()
-  bizdays::load_builtin_calendars()
+  load_builtin_calendars()
+}
+
+.onLoad <- function(libname, pkgname) {
+  op <- options()
+  op.rb3 <- list(
+    rb3.cachedir = NULL
+  )
+  toset <- !(names(op.rb3) %in% names(op))
+  if(any(toset)) options(op.rb3[toset])
+
+  invisible()
 }
\ No newline at end of file
