@@ -1,12 +1,14 @@
-skip_on_cran()
+if (!covr::in_covr()) {
+  skip_on_cran()
+}
 
 test_that("it should download cdi/idi file", {
-  f <- download_data("CDIIDI")
+  f <- download_marketdata("CDIIDI")
   expect_true(file.exists(f))
 })
 
 test_that("it should read cdi/idi file", {
-  f <- download_data("CDIIDI")
+  f <- download_marketdata("CDIIDI")
   df <- read_marketdata(f, template = "CDIIDI")
   expect_true(is(df$taxa, "numeric"))
   expect_true(is(df$indice, "numeric"))
